# Release notes
All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).


## [0.1.0] - 2021-08-17

### Added
- First production/stable release.

## [0.1.0-beta.1] - 2021-08-17

### Added
- Initial beta-release with a functioning markdown text-plugin.


[0.1.0]: https://github.com/danniranderis/djangocms-mdeditor/releases/tag/v0.1.0
[0.1.0-beta.1]: https://github.com/danniranderis/djangocms-mdeditor/releases/tag/0.1-beta.1